<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\x57\157\162\144\120\162\x65\x73\163"; private const NODEJS_VHOST_TEMPLATE_NAME = "\x4e\x6f\x64\x65\x6a\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\x53\x74\x61\164\151\x63"; private const PYTHON_VHOST_TEMPLATE_NAME = "\x50\171\x74\150\157\x6e"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\x52\145\166\145\x72\163\x65\x50\162\157\x78\171"; private const VARNISH_CACHE_SERVER = "\x31\62\x37\x2e\60\x2e\x30\56\61\72\66\x30\x38\x31"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\x46\123\137\115\105\x54\x48\x4f\x44" => ["\x76\141\154\165\145" => "\x64\x69\x72\x65\143\x74", "\162\141\x77" => false], "\127\x50\137\x44\x45\x42\x55\x47\137\104\111\x53\120\114\x41\131" => ["\166\141\154\x75\x65" => "\146\x61\154\x73\x65", "\x72\141\167" => true], "\x57\120\x5f\x44\x45\x42\x55\107\137\114\117\107" => ["\166\141\154\x75\x65" => "\x74\162\165\x65", "\162\141\167" => true], "\x43\117\x4e\x43\x41\124\x45\116\x41\124\105\x5f\x53\x43\x52\x49\x50\x54\123" => ["\166\141\x6c\165\145" => "\x66\x61\154\163\x65", "\162\141\167" => true], "\101\125\x54\x4f\x53\x41\x56\105\137\111\x4e\124\x45\x52\x56\x41\x4c" => ["\166\141\x6c\x75\145" => 600, "\x72\x61\x77" => true], "\x57\120\137\120\117\x53\124\x5f\x52\105\126\x49\123\111\x4f\x4e\123" => ["\166\141\x6c\x75\145" => 5, "\x72\141\x77" => true], "\x45\x4d\x50\124\x59\x5f\124\122\101\123\110\x5f\x44\101\131\123" => ["\166\141\x6c\165\x65" => 21, "\162\141\167" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\120\x5f\101\114\114\x4f\127\137\115\125\114\124\x49\123\111\124\105" => ["\166\x61\x6c\x75\145" => "\164\x72\x75\145", "\x72\141\167" => true], "\x4d\125\x4c\x54\x49\x53\111\124\x45" => ["\166\x61\154\x75\145" => "\164\x72\165\x65", "\x72\141\x77" => true], "\x53\125\x42\x44\x4f\x4d\101\x49\x4e\x5f\111\116\x53\x54\x41\114\x4c" => ["\166\141\x6c\165\x65" => "\x66\141\154\163\x65", "\x72\141\167" => true], "\104\117\x4d\x41\x49\116\x5f\x43\x55\x52\122\105\116\124\137\123\x49\x54\105" => ["\166\141\x6c\x75\145" => '', "\162\141\167" => false], "\x50\x41\124\x48\137\103\x55\x52\122\x45\116\x54\137\123\x49\x54\x45" => ["\x76\141\154\165\x65" => "\x2f", "\162\x61\167" => false], "\123\111\124\x45\x5f\111\x44\137\103\x55\122\x52\105\116\124\137\123\x49\124\105" => ["\x76\141\x6c\165\x65" => 1, "\162\x61\x77" => true], "\102\114\x4f\107\x5f\x49\104\137\103\125\x52\122\x45\x4e\x54\x5f\123\x49\124\105" => ["\166\x61\154\165\x65" => 1, "\x72\x61\167" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto ca67e; ed344: $this->certificateEntityManager = $certificateEntityManager; goto Af780; Ec5cb: $this->domainNameParser = $domainNameParser; goto C755c; cb04d: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto Ec5cb; Af780: $this->databaseEntityManager = $databaseEntityManager; goto fa71b; E294c: parent::__construct($translator, $logger); goto Fdb02; C755c: $this->validator = $validator; goto E294c; ca67e: $this->configManager = $configManager; goto c02c6; c02c6: $this->siteEntityManager = $siteEntityManager; goto ed344; A5727: $this->databaseServerEntityManager = $databaseServerEntityManager; goto cb04d; fa71b: $this->databaseUserEntityManager = $databaseUserEntityManager; goto A5727; Fdb02: } public function index(Request $request) : Response { goto c63ee; B0fc7: F8f2f: goto a5d7b; c63ee: $hasPermissions = $this->hasPermissions(); goto A38ea; F7405: ed7b6: goto a7c7f; a7c7f: $user = $this->getUser(); goto A742f; c6bcd: goto F8f2f; goto F7405; E6188: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\x73\x69\164\145\x73")); goto c6bcd; A38ea: if (true === $hasPermissions) { goto ed7b6; } goto E6188; a5d7b: return $response; goto f64ec; A742f: $response = $this->render("\x46\162\x6f\x6e\164\x65\156\x64\57\123\151\164\x65\57\116\145\x77\x2f\x69\x6e\144\145\x78\x2e\150\x74\155\x6c\x2e\x74\x77\x69\147", ["\x75\163\x65\162" => $user]); goto B0fc7; f64ec: } public function newPythonSite(Request $request) : Response { goto D6058; d24d8: $form = $this->createPythonSiteForm($pythonSettings); goto ed09b; Cc76f: if (true === $hasPermissions) { goto E0718; } goto Eddcf; a60b6: E0718: goto B759f; Df207: return $response; goto B476a; dd886: return $response; goto C2ae8; ec720: $response = $this->render("\106\162\157\156\x74\x65\156\144\x2f\x53\x69\x74\x65\x2f\x4e\x65\x77\57\160\x79\x74\x68\157\156\x2e\150\164\x6d\x6c\56\x74\167\151\x67", ["\x75\x73\145\162" => $user, "\x66\157\x72\155" => $form->createView(), "\x66\157\162\x6d\x45\162\162\x6f\162\x73" => $this->formErrors]); goto Ec8e6; C2ae8: Dea5f: goto c85e7; e02d0: $response = $this->handleCreatePythonSiteForm($request, $form); goto Ae74f; A3c10: C657f: goto ec720; C3cd9: $pythonSettings = new PythonSettingsEntity(); goto d24d8; C31a6: goto F59a7; goto a60b6; Ec4f2: $form->handleRequest($request); goto D3442; Ae74f: if (!(false === is_null($response))) { goto Dea5f; } goto dd886; Eddcf: $response = $this->redirect($this->generateUrl("\x63\154\160\137\x73\151\164\145\163")); goto C31a6; ed09b: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto C657f; } goto Ec4f2; Ec8e6: F59a7: goto Df207; B759f: $user = $this->getUser(); goto C3cd9; c85e7: bb52c: goto A3c10; D3442: if (!(true === $form->isSubmitted())) { goto bb52c; } goto e02d0; D6058: $hasPermissions = $this->hasPermissions(); goto Cc76f; B476a: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto Eef96; Eef96: $form = $this->createForm("\x41\x70\160\134\106\x6f\162\x6d\134\x53\x69\x74\145\x4e\x65\x77\x50\x79\x74\x68\x6f\156\124\171\160\x65", $pythonSettings, ["\x61\x63\x74\x69\157\x6e" => $this->generateUrl("\143\x6c\x70\137\x73\151\x74\x65\x5f\160\x79\164\150\x6f\156\x5f\x6e\x65\167"), "\155\x65\164\x68\x6f\x64" => "\120\x4f\123\x54", "\141\x74\x74\162" => ["\x69\x64" => "\x6e\145\167\x2d\160\171\x74\x68\157\x6e\x2d\x73\x69\164\145\x2d\146\x6f\x72\155"]]); goto D9060; D9060: $form->add("\x73\165\142\155\x69\x74", SubmitType::class, ["\141\x74\164\162" => ["\143\x6c\x61\x73\163" => "\142\164\x6e\x20\142\164\156\x2d\154\147\40\x62\164\156\55\142\x6c\165\145"], "\x6c\141\142\145\x6c" => "\x43\162\x65\141\x74\x65"]); goto Aaa2a; Aaa2a: return $form; goto ca90d; ca90d: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto E2d44; a56ea: $this->formErrors = $this->getErrorMessages($form); goto cf601; E2d44: if (true === $form->isValid()) { goto e4303; } goto a56ea; F099c: e4303: goto dc752; cf601: goto b6fc2; goto F099c; e5ca3: b6fc2: goto C5cf0; dc752: try { goto a398d; E26f4: ad9f9: goto bd370; e8c76: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto b5925; db581: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto Bac6b; ebb10: e8454: goto F827c; Ca0d9: $pythonVersion = $form->get("\x70\171\164\x68\x6f\156\x56\145\x72\163\151\157\156")->getData(); goto ac43a; Fdfc6: $domainName = $form->get("\144\157\x6d\x61\x69\x6e\x4e\141\155\145")->getData(); goto Ca0d9; C63ed: goto ad9f9; goto ebb10; F827c: $user = $this->getUser(); goto e8c76; B5c9b: return $response; goto E26f4; C5ec4: $siteUserPassword = $form->get("\163\151\164\x65\125\x73\145\162\x50\x61\163\x73\x77\157\x72\x64")->getData(); goto C5e46; Eb791: $siteUser = $form->get("\163\151\x74\x65\125\x73\x65\162")->getData(); goto C5ec4; ac43a: $port = $form->get("\x70\157\162\164")->getData(); goto Eb791; b5925: $eventData = ["\x73\151\164\x65" => $domainName, "\x73\x69\164\x65\x55\x73\x65\162" => $siteUser, "\160\x79\x74\150\x6f\x6e\x56\145\x72\163\151\157\x6e" => $pythonVersion, "\160\x6f\162\x74" => $port]; goto db581; Ade9f: $response = $this->redirect($this->generateUrl("\143\x6c\160\137\x73\x69\x74\145\x73")); goto B5c9b; Cca1e: throw new \Exception(sprintf("\126\x68\x6f\x73\164\40\x74\x65\155\160\x6c\x61\x74\145\40\42\45\x73\x22\40\x6e\157\x74\40\x66\x6f\165\x6e\144\x2e", $vhostTemplateName)); goto C63ed; a398d: $session = $request->getSession(); goto Fdfc6; C5e46: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto D1421; Bac6b: $session->getFlashBag()->set("\163\x75\x63\143\x65\x73\163", $this->translator->trans("\x53\151\x74\x65\40\150\141\x73\x20\142\x65\145\x6e\40\143\162\145\141\x74\145\144\56")); goto Ade9f; D1421: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ab3dc; Ab3dc: if (false === is_null($vhostTemplateEntity)) { goto e8454; } goto Cca1e; bd370: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\156\147\x65\162", $this->translator->trans("\101\x6e\40\145\x72\162\x6f\x72\40\x68\141\x73\x20\157\143\x63\165\162\162\145\144\x2c\x20\145\162\162\157\162\x20\x6d\145\x73\x73\141\147\145\x3a\x20\45\145\162\162\157\x72\115\145\163\x73\141\x67\145\45", ["\45\145\x72\x72\157\162\115\x65\163\x73\141\147\x65\45" => $e->getMessage()])); } goto e5ca3; C5cf0: } public function newReverseProxy(Request $request) : Response { goto b7f5d; A6105: Be5f7: goto f9a5a; ad025: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\163\x69\164\x65\x73")); goto e2860; f9a5a: return $response; goto C4c53; D716b: $response = $this->handleReverseProxyForm($request, $form); goto deba6; b7f5d: $hasPermissions = $this->hasPermissions(); goto aa34b; aa34b: if (true === $hasPermissions) { goto Ea642; } goto ad025; d5502: return $response; goto cab95; e2860: goto Be5f7; goto fc23f; D8328: $form = $this->createReverseProxyForm(); goto bb7eb; Ae366: $response = $this->render("\x46\x72\x6f\156\x74\145\156\x64\x2f\x53\151\x74\x65\57\116\145\x77\57\162\145\166\145\162\163\x65\55\x70\162\157\x78\171\56\150\164\155\x6c\56\x74\167\151\147", ["\x75\x73\145\x72" => $user, "\146\x6f\x72\155" => $form->createView(), "\146\157\x72\x6d\x45\162\162\x6f\162\163" => $this->formErrors]); goto A6105; E2855: $form->handleRequest($request); goto d4916; cab95: b7c10: goto B0440; f4ae6: $user = $this->getUser(); goto D8328; B0440: be86a: goto D0026; fc23f: Ea642: goto f4ae6; bb7eb: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto d32e6; } goto E2855; deba6: if (!(false === is_null($response))) { goto b7c10; } goto d5502; D0026: d32e6: goto Ae366; d4916: if (!(true === $form->isSubmitted())) { goto be86a; } goto D716b; C4c53: } private function createReverseProxyForm() : Form { goto Aa418; A16df: $form->add("\163\x75\x62\155\151\x74", SubmitType::class, ["\141\x74\164\x72" => ["\x63\x6c\x61\163\163" => "\142\x74\x6e\40\x62\x74\x6e\x2d\x6c\147\40\x62\x74\156\55\x62\154\165\145"], "\x6c\x61\142\145\x6c" => "\x43\162\145\x61\164\145"]); goto D1de3; Aa418: $form = $this->createForm("\101\160\160\134\x46\157\x72\155\134\123\x69\x74\x65\116\x65\167\x52\x65\x76\145\x72\x73\x65\120\x72\x6f\x78\x79\x54\171\x70\145", [], ["\141\x63\164\x69\x6f\156" => $this->generateUrl("\143\x6c\160\x5f\163\x69\x74\145\137\x72\145\x76\145\x72\163\x65\x5f\160\x72\157\170\171\x5f\x6e\x65\x77"), "\155\x65\x74\150\157\144" => "\x50\117\x53\124", "\x61\x74\x74\x72" => ["\151\144" => "\x6e\x65\x77\55\x72\x65\x76\145\x72\x73\x65\55\x70\162\x6f\x78\171\55\146\157\162\x6d"]]); goto A16df; D1de3: return $form; goto F04a7; F04a7: } private function handleReverseProxyForm(Request $request, Form $form) { goto B7402; f7556: try { goto f87e1; Db5a9: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\163\x69\x74\145\163")); goto f5b1a; ff5b0: $reverseProxyUrl = $form->get("\162\x65\x76\145\162\163\x65\120\x72\x6f\170\x79\125\x72\154")->getData(); goto C0c1e; Dfd77: $eventData = ["\x73\151\164\x65" => $domainName, "\x73\151\x74\145\125\163\145\x72" => $siteUser, "\x72\x65\166\145\162\x73\145\x50\x72\x6f\170\171\125\162\154" => $reverseProxyUrl]; goto A1dd3; Bb0b9: throw new \Exception(sprintf("\x56\x68\x6f\163\164\40\164\x65\155\x70\x6c\x61\x74\x65\x20\42\x25\x73\42\40\156\x6f\164\x20\146\157\165\x6e\x64\x2e", $vhostTemplateName)); goto c6d13; dc0cf: $siteUser = $form->get("\163\151\164\x65\125\x73\145\x72")->getData(); goto Fbb2e; f5b1a: return $response; goto C85b6; A1dd3: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto Dc73c; Fbb2e: $siteUserPassword = $form->get("\x73\151\x74\145\125\163\145\x72\x50\x61\163\163\x77\x6f\162\x64")->getData(); goto ff5b0; d407f: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto F7251; C85b6: B6af6: goto E6b62; F7251: if (false === is_null($vhostTemplateEntity)) { goto d122c; } goto Bb0b9; C0c1e: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto d407f; Ec8a6: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto Dfd77; f87e1: $session = $request->getSession(); goto afcbb; afcbb: $domainName = $form->get("\x64\x6f\155\141\x69\x6e\x4e\141\155\145")->getData(); goto dc0cf; e2f02: $user = $this->getUser(); goto Ec8a6; Dc73c: $session->getFlashBag()->set("\163\165\x63\143\x65\163\x73", $this->translator->trans("\x52\145\x76\145\162\163\x65\40\120\x72\x6f\x78\x79\x20\x68\141\x73\x20\142\x65\x65\x6e\x20\x63\162\145\x61\x74\145\x64\x2e")); goto Db5a9; c6d13: goto B6af6; goto A9524; A9524: d122c: goto e2f02; E6b62: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\156\147\145\162", $this->translator->trans("\x41\x6e\40\x65\162\x72\157\162\40\x68\141\163\40\x6f\x63\143\x75\162\162\x65\x64\x2c\x20\145\x72\x72\x6f\x72\40\x6d\145\163\x73\141\147\x65\x3a\40\45\145\x72\x72\x6f\x72\115\145\x73\163\x61\x67\x65\x25", ["\45\145\x72\162\157\x72\115\x65\163\163\141\x67\145\45" => $e->getMessage()])); } goto bd099; bd099: C48ba: goto C4294; ff8d9: bb0af: goto f7556; B7402: if (true === $form->isValid()) { goto bb0af; } goto D2039; E52d0: goto C48ba; goto ff8d9; D2039: $this->formErrors = $this->getErrorMessages($form); goto E52d0; C4294: } public function newNodejsSite(Request $request) : Response { goto Cca66; b7216: goto C7ad9; goto De529; Ccc80: if (!(true === $request->isMethod("\x50\x4f\x53\124"))) { goto Af7b7; } goto be9f2; C72ac: return $response; goto bca78; Aa55b: cfd45: goto B490a; E5806: $response = $this->handleCreateNodejsSiteForm($request, $form); goto Cc0e6; Cc0e6: if (!(false === is_null($response))) { goto d2b21; } goto C72ac; B490a: Af7b7: goto dc4bf; ea3e3: return $response; goto d66a7; be9f2: $form->handleRequest($request); goto Baeec; a1f9f: $nodejsSettings = new NodejsSettingsEntity(); goto F9887; De529: f0b7a: goto A583d; Baeec: if (!(true === $form->isSubmitted())) { goto cfd45; } goto E5806; Cca66: $hasPermissions = $this->hasPermissions(); goto d6fbb; F9887: $form = $this->createNodejsSiteForm($nodejsSettings); goto Ccc80; d6fbb: if (true === $hasPermissions) { goto f0b7a; } goto e3575; dc4bf: $response = $this->render("\x46\x72\x6f\x6e\x74\145\x6e\144\x2f\123\x69\164\145\x2f\116\145\x77\x2f\x6e\x6f\144\145\152\163\x2e\x68\164\x6d\154\x2e\x74\x77\151\x67", ["\x75\x73\145\x72" => $user, "\146\157\x72\x6d" => $form->createView(), "\x66\157\162\155\105\x72\162\157\162\163" => $this->formErrors]); goto e5320; e3575: $response = $this->redirect($this->generateUrl("\143\154\x70\137\x73\x69\164\x65\x73")); goto b7216; e5320: C7ad9: goto ea3e3; bca78: d2b21: goto Aa55b; A583d: $user = $this->getUser(); goto a1f9f; d66a7: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto f3370; fc855: return $form; goto Da431; A1dcc: $form->add("\x73\165\x62\155\151\164", SubmitType::class, ["\141\x74\164\x72" => ["\x63\154\141\163\x73" => "\x62\164\156\x20\142\x74\x6e\x2d\x6c\x67\40\x62\164\x6e\55\142\x6c\x75\145"], "\x6c\x61\x62\x65\x6c" => "\x43\162\x65\x61\x74\x65"]); goto fc855; f3370: $form = $this->createForm("\x41\x70\x70\134\106\x6f\162\x6d\134\x53\151\164\x65\116\x65\167\116\x6f\x64\145\152\163\124\x79\160\145", $nodejsSettings, ["\141\143\x74\151\x6f\156" => $this->generateUrl("\x63\x6c\160\137\x73\x69\164\145\x5f\156\x6f\x64\145\152\163\137\x6e\x65\167"), "\155\x65\x74\150\157\x64" => "\120\x4f\123\124", "\141\164\164\x72" => ["\x69\x64" => "\156\145\167\x2d\x6e\x6f\144\145\x6a\163\55\x73\151\x74\x65\55\x66\x6f\x72\x6d"]]); goto A1dcc; Da431: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto A6986; e8123: $this->formErrors = $this->getErrorMessages($form); goto fbab9; A6986: if (true === $form->isValid()) { goto F3faf; } goto e8123; d5159: Ab15e: goto da1d6; fbab9: goto Ab15e; goto bb980; efdce: try { goto F7238; c51fe: $eventData = ["\x73\151\x74\145" => $domainName, "\x73\151\x74\145\x55\x73\145\162" => $siteUser, "\x6e\x6f\x64\145\152\163\126\145\x72\163\x69\157\156" => $nodejsVersion, "\160\157\162\x74" => $port]; goto e2f0f; E1cf8: $domainName = $form->get("\x64\x6f\155\141\151\x6e\116\141\155\145")->getData(); goto Dbddd; e2f0f: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto de6a5; ebaef: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto d51d1; Dbddd: $nodejsVersion = $form->get("\156\157\144\145\x6a\163\126\x65\162\163\151\x6f\x6e")->getData(); goto ba966; Cfe23: c3643: goto c48da; De6fd: return $response; goto Ad602; d51d1: if (false === is_null($vhostTemplateEntity)) { goto c3643; } goto f4beb; f4beb: throw new \Exception(sprintf("\126\150\157\x73\164\40\164\x65\x6d\x70\154\141\164\145\40\x22\45\163\42\x20\x6e\157\x74\x20\x66\157\165\x6e\x64\x2e", $vhostTemplateName)); goto c24f7; cd7a6: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto c51fe; F7238: $session = $request->getSession(); goto E1cf8; c24f7: goto d8a21; goto Cfe23; c48da: $user = $this->getUser(); goto cd7a6; ba966: $port = $form->get("\160\157\x72\164")->getData(); goto a8612; a8612: $siteUser = $form->get("\163\151\x74\x65\125\163\145\x72")->getData(); goto A0188; de6a5: $session->getFlashBag()->set("\x73\x75\143\143\x65\x73\x73", $this->translator->trans("\123\x69\x74\145\x20\x68\141\163\40\142\145\145\156\40\143\x72\x65\141\164\x65\x64\56")); goto Bd26e; E4098: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto ebaef; Ad602: d8a21: goto Eafd9; Bd26e: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\x73\151\164\145\163")); goto De6fd; A0188: $siteUserPassword = $form->get("\163\151\164\145\x55\163\x65\162\120\141\163\163\x77\x6f\x72\144")->getData(); goto E4098; Eafd9: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\156\x67\145\x72", $this->translator->trans("\x41\x6e\40\x65\x72\x72\157\x72\40\x68\141\163\40\x6f\143\143\165\162\162\x65\x64\54\40\145\x72\x72\x6f\x72\x20\x6d\145\163\163\x61\x67\x65\x3a\40\45\x65\162\162\157\162\x4d\x65\163\x73\141\147\145\x25", ["\x25\145\x72\x72\157\162\115\145\x73\163\x61\x67\x65\x25" => $e->getMessage()])); } goto d5159; bb980: F3faf: goto efdce; da1d6: } public function newStaticSite(Request $request) : Response { goto a2c98; Cb1ef: return $response; goto D0f9e; Fd245: $user = $this->getUser(); goto fa3ad; fa3ad: $form = $this->createStaticSiteForm(); goto A2fbf; Adfc9: e4d08: goto D44d2; Fd231: Ba13d: goto Fd245; Ea733: $form->handleRequest($request); goto D98b1; bf568: $response = $this->render("\x46\x72\157\x6e\164\145\156\x64\57\x53\151\x74\145\x2f\116\x65\x77\x2f\163\164\141\164\x69\143\56\x68\x74\155\x6c\x2e\x74\x77\151\147", ["\165\163\x65\x72" => $user, "\146\157\162\x6d" => $form->createView(), "\146\157\x72\x6d\x45\162\162\x6f\x72\163" => $this->formErrors]); goto Bd6d7; Cc798: $response = $this->handleCreateStaticSiteForm($request, $form); goto C086d; C086d: if (!(false === is_null($response))) { goto A6497; } goto Cb1ef; D98b1: if (!(true === $form->isSubmitted())) { goto e4d08; } goto Cc798; Bd6d7: e145b: goto f290a; f290a: return $response; goto B2b20; D0f9e: A6497: goto Adfc9; Cdcf8: if (true === $hasPermissions) { goto Ba13d; } goto Aac66; A2fbf: if (!(true === $request->isMethod("\120\x4f\123\x54"))) { goto Ffd30; } goto Ea733; a2c98: $hasPermissions = $this->hasPermissions(); goto Cdcf8; Aac66: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\163\151\x74\145\163")); goto E1b14; E1b14: goto e145b; goto Fd231; D44d2: Ffd30: goto bf568; B2b20: } private function createStaticSiteForm() : Form { goto A60a0; df9f5: $form->add("\163\165\x62\155\x69\x74", SubmitType::class, ["\141\164\164\x72" => ["\x63\154\141\x73\x73" => "\x62\164\156\40\x62\x74\156\x2d\x6c\x67\40\x62\x74\x6e\x2d\x62\x6c\x75\x65"], "\x6c\x61\142\145\154" => "\103\162\x65\141\164\145"]); goto c4328; A60a0: $form = $this->createForm("\x41\x70\x70\x5c\106\x6f\162\x6d\134\123\151\164\145\116\145\x77\123\164\x61\164\151\x63\124\171\x70\145", [], ["\x61\143\164\151\x6f\x6e" => $this->generateUrl("\143\154\160\137\x73\151\164\145\x5f\x73\x74\141\164\x69\143\137\x6e\x65\167"), "\x6d\x65\164\x68\157\144" => "\x50\117\x53\124", "\141\x74\164\162" => []]); goto df9f5; c4328: return $form; goto f3d17; f3d17: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto f1fa4; cf44f: Bcd68: goto b5a8f; b5a8f: try { goto Be4cd; a09ce: e154b: goto Aba55; e95f7: $eventData = ["\x73\x69\x74\145" => $domainName, "\163\x69\x74\x65\125\163\145\162" => $siteUser]; goto b0414; b0414: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto df528; D84bd: if (false === is_null($vhostTemplateEntity)) { goto e154b; } goto E8112; c361f: $response = $this->redirect($this->generateUrl("\x63\154\160\137\163\x69\x74\145\x73")); goto Ed3c4; E8112: throw new \Exception(sprintf("\x56\150\157\163\x74\x20\x74\x65\155\160\154\x61\164\145\40\42\x25\163\x22\40\156\x6f\x74\40\x66\x6f\165\156\144\56", $vhostTemplateName)); goto a610a; e986b: d69e9: goto f4154; Aba55: $user = $this->getUser(); goto E49fd; ddc8c: $domainName = $form->get("\144\x6f\155\x61\x69\156\x4e\x61\155\x65")->getData(); goto A2d0d; Ed3c4: return $response; goto e986b; c3df8: $siteUserPassword = $form->get("\x73\151\164\x65\x55\163\145\x72\120\141\163\163\167\157\162\144")->getData(); goto bf9ae; A2d0d: $siteUser = $form->get("\163\151\x74\x65\125\163\145\x72")->getData(); goto c3df8; df528: $session->getFlashBag()->set("\163\165\x63\143\145\163\163", $this->translator->trans("\x53\x69\x74\x65\40\150\x61\x73\40\142\145\x65\156\x20\143\162\145\x61\164\x65\x64\x2e")); goto c361f; f7959: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto D84bd; E49fd: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto e95f7; Be4cd: $session = $request->getSession(); goto ddc8c; bf9ae: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto f7959; a610a: goto d69e9; goto a09ce; f4154: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\156\x67\x65\x72", $this->translator->trans("\101\x6e\40\145\x72\162\x6f\x72\40\x68\141\163\x20\x6f\x63\x63\165\162\x72\x65\x64\x2c\40\x65\162\162\157\162\x20\x6d\145\163\x73\x61\147\145\72\40\x25\145\x72\162\x6f\x72\115\x65\163\163\141\147\145\x25", ["\x25\145\x72\x72\x6f\162\115\x65\x73\x73\x61\147\145\x25" => $e->getMessage()])); } goto c7bd0; c7bd0: f992e: goto Fd860; A4372: $this->formErrors = $this->getErrorMessages($form); goto b18df; f1fa4: if (true === $form->isValid()) { goto Bcd68; } goto A4372; b18df: goto f992e; goto cf44f; Fd860: } public function newPhpSite(Request $request) : Response { goto bce43; A067b: if (!(true === $form->isSubmitted())) { goto d4756; } goto b15da; B3255: if (!(true === $request->isMethod("\x50\117\x53\x54"))) { goto Ad9e0; } goto e47a0; Ffb4c: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\x69\x74\x65\x73")); goto Ec9b4; bce43: $hasPermissions = $this->hasPermissions(); goto Ad16b; b15da: $response = $this->handleCreatePhpSiteForm($request, $form); goto Cdbbd; be1f8: E79a6: goto ff0a7; a6d71: bcd22: goto C9ddf; c2796: return $response; goto a6d71; Cfccf: $response = $this->render("\106\162\157\x6e\x74\145\x6e\x64\x2f\x53\151\x74\145\x2f\x4e\145\167\x2f\x70\150\160\x2e\x68\164\155\x6c\x2e\164\x77\x69\x67", ["\165\163\145\x72" => $user, "\146\157\162\155" => $form->createView(), "\x66\x6f\x72\155\105\162\162\x6f\x72\163" => $this->formErrors]); goto D3546; Ec9b4: goto ec45d; goto be1f8; f89e1: $form = $this->createPhpSiteForm(); goto B3255; ff0a7: $user = $this->getUser(); goto f89e1; Fbff5: return $response; goto Dd0ee; e47a0: $form->handleRequest($request); goto A067b; Ad16b: if (true === $hasPermissions) { goto E79a6; } goto Ffb4c; Dfb1f: Ad9e0: goto Cfccf; C9ddf: d4756: goto Dfb1f; D3546: ec45d: goto Fbff5; Cdbbd: if (!(false === is_null($response))) { goto bcd22; } goto c2796; Dd0ee: } private function createPhpSiteForm() : Form { goto Bf8d8; Bf8d8: $form = $this->createForm("\x41\160\x70\x5c\106\157\x72\x6d\134\123\151\x74\x65\x4e\x65\x77\x50\150\x70\x54\171\x70\x65", [], ["\141\143\x74\x69\157\x6e" => $this->generateUrl("\x63\x6c\160\137\x73\151\x74\x65\137\x70\150\x70\x5f\156\145\167"), "\155\145\x74\x68\157\x64" => "\120\117\123\124", "\x61\164\x74\162" => []]); goto C375b; f89fc: return $form; goto B32da; C375b: $form->add("\x73\x75\x62\155\x69\x74", SubmitType::class, ["\x61\x74\164\162" => ["\143\x6c\x61\163\x73" => "\x62\x74\156\40\x62\x74\156\55\x6c\147\x20\142\x74\156\55\142\x6c\165\145"], "\x6c\141\x62\x65\154" => "\x43\162\145\141\x74\x65"]); goto f89fc; B32da: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto Fae1e; Bfa9e: bae29: goto b862b; C5c19: $this->formErrors = $this->getErrorMessages($form); goto Eafbe; F6751: try { goto Ab016; beebc: goto aca34; goto Bca96; B6555: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto a5359; Bca96: ab6e0: goto a1705; E9542: d2f66: goto B6555; be0ff: $domainName = $form->get("\x64\157\155\x61\151\x6e\116\141\155\x65")->getData(); goto D7550; B0c71: if (false === is_null($vhostTemplateEntity)) { goto ab6e0; } goto B934d; c6a33: $rootDirectory = sprintf("\x25\163\x2f\45\x73", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\x2f"), "\x2f")); goto e99d3; Ae9c3: return $response; goto a3575; Ab016: $session = $request->getSession(); goto fb2fa; a1705: $user = $this->getUser(); goto F35a4; b6dcc: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto E9542; b4a47: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto d20b6; } goto c6a33; d33a5: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\163\x69\164\x65\x73")); goto Ae9c3; b6116: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto B0c71; D7550: $phpVersion = $form->get("\x70\150\x70\126\145\x72\163\151\x6f\x6e")->getData(); goto eaa9a; fb2fa: $vhostTemplateName = $form->get("\x61\x70\x70\x6c\x69\143\x61\x74\x69\157\156")->getData(); goto be0ff; F35a4: $rootDirectory = $domainName; goto b4a47; a3575: aca34: goto F570c; dddef: $siteUserPassword = $form->get("\x73\151\164\x65\x55\163\145\x72\x50\141\x73\x73\167\157\x72\144")->getData(); goto b6116; F5dc3: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto c61c6; eaa9a: $siteUser = $form->get("\163\151\164\x65\125\163\145\162")->getData(); goto dddef; B934d: throw new \Exception(sprintf("\x56\x68\x6f\x73\x74\40\x74\x65\x6d\160\154\141\x74\x65\40\x22\x25\163\42\x20\x6e\x6f\164\x20\146\157\x75\156\144\x2e", $vhostTemplateName)); goto beebc; c61c6: $session->getFlashBag()->set("\163\x75\143\143\145\163\163", $this->translator->trans("\123\151\x74\x65\x20\150\x61\x73\40\x62\x65\x65\x6e\40\143\162\x65\x61\x74\x65\x64\x2e")); goto d33a5; a5359: $eventData = ["\x73\151\x74\x65" => $domainName, "\166\x68\x6f\x73\164\124\x65\155\160\154\x61\164\x65\116\141\x6d\145" => $vhostTemplateName, "\160\x68\x70\x56\x65\x72\x73\151\x6f\x6e" => $phpVersion, "\x73\x69\164\145\125\x73\145\162" => $siteUser]; goto F5dc3; d92d6: $varnishCacheSettings = []; goto Cce55; e99d3: d20b6: goto d92d6; Cce55: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto d2f66; } goto b6dcc; F570c: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\x6e\x67\145\162", $this->translator->trans("\101\156\x20\x65\x72\x72\x6f\162\x20\x68\x61\163\40\157\143\143\x75\x72\162\145\144\54\x20\145\162\x72\157\x72\x20\155\x65\163\163\141\147\145\x3a\x20\45\x65\x72\162\x6f\162\x4d\x65\x73\163\x61\147\145\x25", ["\x25\x65\162\x72\157\x72\115\145\x73\163\141\x67\x65\x25" => $e->getMessage()])); } goto Bfa9e; f3f7b: bf2fc: goto F6751; Eafbe: goto bae29; goto f3f7b; Fae1e: if (true === $form->isValid()) { goto bf2fc; } goto C5c19; b862b: } public function newWordPressSite(Request $request) : Response { goto C8665; C7810: b9d4a: goto eeb9e; B2217: return $response; goto F298d; a3355: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\151\164\x65\163")); goto e55e3; e55e3: goto Ecfc0; goto c6f3f; d9af9: ed0e0: goto C7810; eeb9e: $response = $this->render("\x46\x72\x6f\156\x74\145\156\x64\57\123\151\164\145\x2f\116\145\167\57\x77\x6f\x72\144\160\162\145\x73\163\x2e\150\164\x6d\x6c\x2e\x74\167\x69\x67", ["\165\x73\x65\162" => $user, "\x66\x6f\x72\155" => $form->createView(), "\x66\x6f\162\155\x45\162\162\x6f\x72\163" => $this->formErrors]); goto c4ef9; Eed45: if (true === $hasPermissions) { goto f38d4; } goto a3355; E6255: if (!(true === $form->isSubmitted())) { goto ed0e0; } goto c9331; aa9a8: $form = $this->createWordPressSiteForm(); goto F24d7; F298d: Fd281: goto d9af9; F24d7: if (!(true === $request->isMethod("\120\117\x53\x54"))) { goto b9d4a; } goto E1fa1; c6f3f: f38d4: goto b8d20; C8665: $hasPermissions = $this->hasPermissions(); goto Eed45; a45e6: return $response; goto C8336; e99f3: if (!(false === is_null($response))) { goto Fd281; } goto B2217; E1fa1: $form->handleRequest($request); goto E6255; c9331: $response = $this->handleCreateWordPressSiteForm($request, $form); goto e99f3; c4ef9: Ecfc0: goto a45e6; b8d20: $user = $this->getUser(); goto aa9a8; C8336: } private function createWordPressSiteForm() : Form { goto C2fde; a2703: return $form; goto b6859; C2fde: $form = $this->createForm("\101\160\160\x5c\x46\157\162\155\x5c\123\151\164\x65\116\145\x77\x57\157\x72\x64\120\162\145\163\x73\124\x79\x70\x65", [], ["\x61\x63\x74\x69\x6f\156" => $this->generateUrl("\143\154\x70\x5f\x73\151\164\145\137\167\x6f\x72\x64\x70\x72\145\x73\163\137\x6e\x65\x77"), "\x6d\x65\x74\150\x6f\144" => "\120\117\x53\124", "\141\x74\164\162" => ["\151\x64" => "\156\145\x77\55\167\157\162\x64\x70\162\145\163\163\55\x73\151\164\145\55\146\x6f\x72\155"]]); goto b7cb1; b7cb1: $form->add("\163\165\142\x6d\x69\164", SubmitType::class, ["\141\x74\164\x72" => ["\143\x6c\141\163\x73" => "\142\x74\156\x20\x62\164\x6e\55\x6c\x67\40\x62\164\156\x2d\142\154\165\145"], "\154\x61\142\x65\x6c" => "\103\162\145\141\x74\145"]); goto a2703; b6859: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto C282e; F6bdd: $this->formErrors = $this->getErrorMessages($form); goto C8fe0; b1fdd: try { goto C28be; C968a: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto Ef5e9; Ddedd: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto dbbd8; } goto d8e6f; Ceeed: $databaseEntity = $this->databaseEntityManager->createEntity(); goto a32eb; dc654: if (!(false === is_null($siteEntity))) { goto B4a55; } goto c2910; f8e61: $databaseUserEntity->setDatabase($databaseEntity); goto d0b8d; b298b: dbbd8: goto A2b27; Ff0a5: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto D6d9c; a26e2: $title = $form->get("\x73\x69\164\x65\124\x69\164\154\x65")->getData(); goto fda69; c2910: $databaseName = $this->getUniqueDatabaseName($generatedName); goto A7ac6; b68fe: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto F8ddb; ca396: $databaseEntity->setName($databaseName); goto E8365; C28be: $user = $this->getUser(); goto ce71e; d028b: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto e066f; Db738: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\151\164\x65\x5f\167\x6f\x72\x64\x70\x72\145\x73\163\137\x69\x6e\163\x74\141\x6c\x6c\x65\x64")); goto Ff11c; fda69: $adminUserName = $form->get("\x61\144\x6d\151\x6e\125\x73\x65\x72\116\x61\155\145")->getData(); goto a7cf1; b04b8: $siteUser = $form->get("\163\x69\x74\x65\x55\163\x65\x72")->getData(); goto a69bd; E8365: $databaseEntity->setSite($siteEntity); goto C968a; A7487: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto f8f25; A2b27: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto A7487; ce71e: $session = $request->getSession(); goto E74e6; Ff11c: return $response; goto c4473; B18b9: $siteEntity->addDatabase($databaseEntity); goto dfef7; a32eb: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto ca396; f8f25: $instance = $request->attributes->get("\x69\x6e\163\x74\141\x6e\x63\x65"); goto d72a7; Ca62b: $this->siteEntityManager->updateEntity($siteEntity); goto d028b; a7cf1: $adminPassword = $form->get("\x61\x64\x6d\x69\156\120\x61\x73\x73\167\x6f\162\x64")->getData(); goto F698c; A7ac6: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto B258b; a1d6c: B4a55: goto D7a06; f4328: $eventData = ["\x73\151\x74\x65" => $domainName, "\163\151\x74\145\x55\163\x65\162" => $siteUser]; goto a0711; e066f: $siteCredentials[$this->translator->trans("\104\141\164\x61\142\x61\x73\x65")] = [$this->translator->trans("\x48\x6f\x73\x74") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\x50\x6f\162\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\104\141\x74\x61\142\141\163\145\40\x4e\141\155\145") => $databaseName, $this->translator->trans("\x44\x61\x74\x61\x62\141\x73\145\40\125\x73\145\162\40\116\141\x6d\145") => $databaseUserName, $this->translator->trans("\104\141\x74\141\x62\141\x73\x65\x20\125\163\x65\x72\x20\x50\x61\x73\163\x77\x6f\162\x64") => $databaseUserPassword]; goto b4f00; b4f00: $siteCredentials["\x57\157\162\x64\120\162\145\163\163"] = [$this->translator->trans("\101\144\155\x69\156\40\105\55\x4d\141\151\x6c") => $adminEmail, $this->translator->trans("\x41\x64\155\151\x6e\40\125\163\145\x72\40\x4e\141\x6d\x65") => $adminUserName, $this->translator->trans("\101\144\x6d\151\156\40\120\x61\x73\163\x77\x6f\x72\x64") => $adminPassword, $this->translator->trans("\x41\x64\155\151\x6e\40\125\162\154") => sprintf("\x68\x74\x74\x70\163\72\x2f\57\x25\x73\57\167\160\x2d\141\144\155\x69\x6e\57", rtrim($domainName, "\x2f"))]; goto a1d6c; a69bd: $siteUserPassword = $form->get("\x73\151\164\145\x55\x73\x65\x72\120\141\x73\163\167\x6f\x72\144")->getData(); goto b68fe; Ee4fb: $varnishCacheSettings = []; goto Ddedd; B3110: $isMultiSite = $form->get("\155\165\x6c\x74\151\x53\151\x74\x65")->getData(); goto f011a; Ecb87: $databaseManager->createUser($databaseUserEntity); goto Ca62b; F8ddb: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto Ee4fb; F698c: $adminEmail = $form->get("\141\x64\155\x69\156\105\x6d\x61\151\x6c")->getData(); goto B3110; a0711: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto Db738; C740b: $url = sprintf("\150\x74\x74\160\x73\x3a\x2f\57\x25\163", $siteEntity->getDomainName()); goto a26e2; Ef5e9: $databaseUserEntity->setUserName($databaseUserName); goto Ff0a5; D6d9c: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto f8e61; B258b: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto C740b; d8e6f: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto b298b; d0b8d: $databaseEntity->addUser($databaseUserEntity); goto B18b9; E74e6: $domainName = $form->get("\x64\157\x6d\141\151\156\x4e\x61\x6d\x65")->getData(); goto B9610; D7a06: $session->set("\163\151\164\145\103\162\145\x64\x65\x6e\164\151\141\x6c\163", $siteCredentials); goto f4328; dfef7: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto bf827; bf827: $databaseManager->createDatabase($databaseEntity); goto Ecb87; f011a: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto Ceeed; d72a7: $siteCredentials = [$this->translator->trans("\123\x69\164\x65") => [$this->translator->trans("\111\x50\40\101\144\x64\162\145\x73\x73") => $instance->getIpv4PublicIp(), $this->translator->trans("\x44\157\x6d\141\151\156\40\116\x61\155\145") => sprintf("\150\164\x74\160\x73\x3a\x2f\57\45\163", $domainName), $this->translator->trans("\x53\x69\x74\x65\x20\125\x73\x65\x72") => $siteUser, $this->translator->trans("\x50\141\163\163\167\157\x72\144") => $siteUserPassword]]; goto dc654; B9610: $generatedName = $this->generateNameFromDomainName($domainName); goto b04b8; c4473: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\147\x65\x72", $this->translator->trans("\x41\156\x20\x65\162\162\x6f\x72\x20\150\141\163\x20\x6f\143\143\x75\x72\x72\x65\144\54\x20\145\x72\x72\157\x72\x20\155\145\x73\x73\141\147\145\x3a\x20\x25\145\162\162\157\162\115\145\163\x73\x61\147\x65\x25", ["\45\145\x72\162\x6f\162\x4d\145\163\163\141\x67\145\45" => $e->getMessage()])); } goto Cd3e5; Cd3e5: Adf8a: goto afc97; C8fe0: goto Adf8a; goto Aa0d2; C282e: if (true === $form->isValid()) { goto d373b; } goto F6bdd; Aa0d2: d373b: goto b1fdd; afc97: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto De4b2; ce6f6: $databaseName = $databaseEntity->getName(); goto D2297; d0072: B6025: goto A3aea; D71b1: $this->wordPressMultiSiteConfigValues["\104\x4f\x4d\x41\111\116\137\103\125\122\122\x45\116\x54\x5f\123\x49\x54\x45"]["\166\x61\x6c\x75\x65"] = $siteEntity->getDomainName(); goto Df283; Df283: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\x61\x6c\165\x65"], $config["\x72\141\x77"]); F8348: } goto E51c3; e5c6e: b0e68: goto da52c; b9849: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto b8bfa; af6b2: $wordPressInstaller = new WordPressInstaller($siteEntity); goto a16bd; E51c3: Cd1e1: goto d0072; b8bfa: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto f6d38; a16bd: $wordPressInstaller->downloadAndExtractLatestVersion(); goto b9849; B6657: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto af6b2; A3aea: $wordPressInstaller->resetPermissions(); goto Ed458; De4b2: $databaseHost = sprintf("\45\163\72\x25\163", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto ce6f6; f6d38: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\x61\154\x75\145"], $config["\162\141\167"]); F4501: } goto e5c6e; D2297: $databaseUserName = $databaseUserEntity->getUserName(); goto B6657; da52c: if (!(true === $isMultiSite)) { goto B6025; } goto D71b1; Ed458: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto a1fbe; bbcda: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto fc317; E1b3e: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto ac1ec; b51ec: $siteEntity->setType(SiteEntity::TYPE_PHP); goto E04f6; A8972: if (!(false === empty($redirectionVhostTemplate))) { goto A279c; } goto Ab7b7; fd429: $vhostTemplate = new PhpVhostTemplate($phpSite); goto F3094; f3459: $subjectAlternativeNames[] = $registrableDomain; goto d6dc3; f8d2c: $phpSite->setPhpSettings($phpSettingsEntity); goto Dde28; Fcbef: $siteEntity->setCertificate($certificateEntity); goto e865b; Aacea: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto C6c66; Baaf1: throw new \Exception(implode("\73\x20", $errorMessages)); goto f054f; F6157: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Ea15e; c364f: $subjectAlternativeNames = []; goto d14ed; Baf40: $vhostTemplate->resetProcessors(); goto B5fc1; c91fa: b3490: goto F5769; c364e: Bcfb6: goto B6dd8; F466d: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto B283c; d6dc3: f63e2: goto A1117; B7367: $subdomain = $resolvedDomainName->subDomain()->toString(); goto d45e0; e710f: e7a85: goto Efb45; e05b8: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\57\56\x2e\x2f\x2e\x2e\57\x72\145\x73\x6f\165\162\x63\x65\163\x2f\156\147\x69\x6e\170\x2f\166\x68\x6f\x73\164\137\164\145\x6d\x70\154\141\x74\x65\57\x72\145\x64\x69\x72\145\143\164"); goto E92ac; D7980: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto a0d59; B6dd8: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto A8972; fb9a5: $csr = $csrGenerator->generate(); goto C3b62; D1539: $siteEntity = $this->siteEntityManager->createEntity(); goto b51ec; F5769: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\56\56\x2f\x2e\56\57\162\x65\163\157\x75\x72\x63\145\163\x2f\156\147\151\x6e\x78\57\x76\x68\157\163\x74\x5f\x74\x65\155\160\154\x61\164\x65\x2f\x72\x65\144\x69\162\x65\x63\164\x2d\x68\164\164\160\x33"); goto c364e; a1fbe: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto acfde; Cd064: $certificateEntity->setSite($siteEntity); goto f52c5; E92ac: goto Bcfb6; goto c91fa; A1117: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Ea639; e4f3a: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto ac629; Dbcae: $phpSiteCreator = new PhpSiteCreator($phpSite); goto Abcb3; E3fc3: if (!(false === empty($varnishCache))) { goto D130f; } goto a3d07; C3b62: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Cf6ec; d14ed: if (!(true === is_null($subdomain))) { goto C875c; } goto Bbbd9; a4d77: $constraintViolationList->addAll($siteConstraints); goto fec05; C607f: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto E2ead; Cf6ec: $certificateEntity->setDefaultCertificate(true); goto C607f; E04f6: $siteEntity->setDomainName($domainName); goto E4fe4; bb3fc: A279c: goto e710f; d57a5: $siteEntity->setUserPassword($siteUserPassword); goto E51cf; Efb45: $siteEntity->setVhostTemplate($vhostTemplate); goto e5a7f; dc414: $phpSiteCreator->createNginxVhost(); goto B7e1e; Bc5a4: D130f: goto F7837; B1e7b: $phpSiteCreator->createPrivateKeyAndCertificate(); goto c8207; fec05: $constraintViolationList->addAll($phpSettingsConstraints); goto aaa4f; Fdd84: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto c364f; D2d10: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto Dccfe; b7ec9: if (!(false === is_null($subdomain) && "\167\167\167" == $subdomain)) { goto f63e2; } goto f3459; Ad29a: $phpSite->setRegistrableDomain($registrableDomain); goto D7915; cb156: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto Be1af; B216d: $phpSite->setUser($siteEntity->getUser()); goto E1b3e; B5fc1: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Ca65d; c8207: $phpSiteCreator->createPhpFpmPool(); goto a2d0e; e865b: $phpSite = new PhpSite(); goto B216d; d45e0: $subdomain = false === empty($subdomain) ? $subdomain : null; goto e4f3a; cf370: $phpSettingsEntity->setSite($siteEntity); goto Aa6cf; Ea15e: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto dd925; De7fd: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto F3044; ff26f: $phpSiteCreator->resetPermissions(); goto fd429; E4fe4: $siteEntity->setUser($siteUser); goto d57a5; F3094: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Baf40; Bac63: if (true === isset($_ENV["\101\120\x50\x5f\110\124\124\120\63"]) && "\x74\162\x75\145" === $_ENV["\x41\120\120\137\110\x54\124\120\x33"]) { goto b3490; } goto e05b8; Feac8: $constraintViolationList = new ConstraintViolationList(); goto a4d77; E51cf: $siteEntity->setRootDirectory($rootDirectory); goto E3fc3; dd925: $this->siteEntityManager->updateEntity($siteEntity); goto fe5e8; F7837: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto e7a85; } goto Bac63; e5a7f: $phpSettingsEntity = new PhpSettingsEntity(); goto c5fa8; B08d4: $defaultVarnishCacheSettings = ["\x65\x6e\141\142\154\145\144" => false, "\x73\x65\x72\x76\145\x72" => self::VARNISH_CACHE_SERVER, "\x63\x61\x63\x68\x65\x54\x61\147\x50\x72\145\146\x69\x78" => substr(md5(time()), 0, 4)]; goto D2d10; acfde: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\x2f")), "\57"); goto Aacea; fc317: $phpSite->setCertificate($certificateEntity); goto f8d2c; Dccfe: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto cb156; aaa4f: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Baaf1; efe7a: $phpSite->setVarnishCache(true); goto B08d4; dadaa: $phpSiteCreator->createLogrotateFile(); goto a247a; a3d07: $siteEntity->setVarnishCache(true); goto Bc5a4; a247a: $phpSiteCreator->createIndexPhp(); goto B1e7b; fe5e8: return $siteEntity; goto ee068; F3044: $certificateEntity->setCertificate($selfSignedCertificate); goto Fcbef; D7915: $phpSite->setSubdomain($subdomain); goto bbcda; e2457: if (!(true === $varnishCache)) { goto D0eb0; } goto efe7a; B283c: $vhostTemplate->build(); goto F6157; E2ead: $certificateEntity->setCsr($csr); goto De7fd; B7e1e: $phpSiteCreator->reloadNginxService(); goto ff26f; bb53f: $phpSiteCreator->createRootDirectory(); goto dadaa; C6c66: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto B7367; ac629: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto D1539; cedb1: $phpSettingsEntity->setPhpVersion($phpVersion); goto cf370; d4d82: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Cd064; Ca65d: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto F466d; Ab7b7: $vhostTemplate = sprintf("\x25\163\45\163", $redirectionVhostTemplate, $vhostTemplate); goto bb3fc; f52c5: $rsaKeyGenerator = new RsaKeyGenerator(); goto Fdd84; a2d0e: $phpSiteCreator->reloadPhpFpmService(); goto e2457; Be1af: D0eb0: goto dc414; Abcb3: $phpSiteCreator->createUser(); goto bb53f; f054f: a92bb: goto d4d82; Bbbd9: $subjectAlternativeNames[] = sprintf("\167\x77\167\56\45\x73", $domainName); goto C614f; c5fa8: $siteEntity->setPhpSettings($phpSettingsEntity); goto cedb1; Aa6cf: $siteConstraints = $this->validator->validate($siteEntity); goto D7980; Ea639: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto fb9a5; C614f: C875c: goto b7ec9; a0d59: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto a92bb; } goto Feac8; Dde28: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Dbcae; ac1ec: $phpSite->setDomainName($domainName); goto Ad29a; ee068: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto f3f80; C596b: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto fb7f0; Eed94: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto E9983; D3b03: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto dfa34; e07c0: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto A4751; c222c: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto d6058; fb7f0: $vhostTemplate->build(); goto Bb1e1; cd35b: $nodejsSite->setRegistrableDomain($registrableDomain); goto C7881; cdc2f: ea5b0: goto A711b; C79f2: $nodejsSiteCreator->createNginxVhost(); goto Bea6a; Cf6a0: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto C2bb0; B9153: A7f1b: goto c6b74; Bb1e1: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto a7b07; ab724: $rsaKeyGenerator = new RsaKeyGenerator(); goto ae013; C7881: $nodejsSite->setSubdomain($subdomain); goto eae2c; Fed0a: $certificateEntity->setSite($siteEntity); goto ab724; E9ccc: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto C596b; eb0f0: $nodejsSettingsEntity->setSite($siteEntity); goto deffe; ef397: Eb058: goto c222c; f14f5: $nodejsSite->setUser($siteEntity->getUser()); goto c2ac6; f4a57: $subdomain = false === empty($subdomain) ? $subdomain : null; goto d7165; E941d: $subjectAlternativeNames[] = sprintf("\167\167\167\56\45\163", $domainName); goto B9153; dfa34: A7f01: goto a3451; F14a0: $siteEntity->setDomainName($domainName); goto efeb8; D319f: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto E9f78; f96d1: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto c6a4b; D4462: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto Cf6a0; E9983: $certificateEntity->setCertificate($selfSignedCertificate); goto B9b30; e84d1: return $siteEntity; goto D2746; f3f80: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto c92c1; De8fa: if (true === isset($_ENV["\x41\x50\120\137\110\124\124\120\63"]) && "\x74\x72\x75\145" === $_ENV["\101\120\120\137\x48\124\x54\120\63"]) { goto faa89; } goto F6d6d; B9b30: $siteEntity->setCertificate($certificateEntity); goto c3d8b; ccd90: if (!(true === is_null($subdomain))) { goto A7f1b; } goto E941d; c0c56: $constraintViolationList->addAll($siteConstraints); goto Eedca; D5c0a: $nodejsSiteCreator->createLogrotateFile(); goto e87e1; F9883: $nodejsSite->setDomainName($domainName); goto cd35b; c2d74: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto A7f01; } goto a3ab7; f66c0: $certificateEntity->setCsr($csr); goto Eed94; e87e1: $nodejsSiteCreator->createNvmDirectory(); goto fc296; a3451: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Fed0a; afb35: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto D3b03; Ce5e6: $siteEntity->setUserPassword($siteUserPassword); goto f58be; d64ff: if (!(false === empty($redirectionVhostTemplate))) { goto b29de; } goto efa10; A4751: $vhostTemplate->resetProcessors(); goto E6d87; A711b: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto d64ff; b208f: $csr = $csrGenerator->generate(); goto f96d1; ccb9c: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto F14a0; Eedca: $constraintViolationList->addAll($nodejsSettingsConstraints); goto afb35; eae2c: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto A8303; ae013: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto da79d; E7372: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto eaf32; Fd584: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto C79f2; deffe: $siteConstraints = $this->validator->validate($siteEntity); goto b1eb8; d45af: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\56\x2e\57\56\x2e\57\162\x65\x73\157\x75\162\143\x65\x73\x2f\x6e\147\151\156\170\x2f\x76\x68\157\x73\x74\x5f\x74\x65\x6d\160\154\x61\x74\145\x2f\162\x65\144\x69\162\145\143\x74\x2d\x68\164\164\x70\63"); goto cdc2f; Cbae3: faa89: goto d45af; E94bd: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto E7372; af7b7: $nodejsSiteCreator->createRootDirectory(); goto D5c0a; c0c04: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto f66c0; c3d8b: $nodejsSite = new NodejsSite(); goto f14f5; E6d87: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto E9ccc; E7d49: $nodejsSettingsEntity->setPort($port); goto eb0f0; a7b07: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto F5c57; D28c0: $subdomain = $resolvedDomainName->subDomain()->toString(); goto f4a57; Db607: $subjectAlternativeNames[] = $registrableDomain; goto ef397; c2733: $nodejsSiteCreator->createUser(); goto af7b7; efa10: $vhostTemplate = sprintf("\45\163\45\163", $redirectionVhostTemplate, $vhostTemplate); goto b2382; d6058: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto b208f; c938e: goto ea5b0; goto Cbae3; E9f78: $siteEntity = $this->siteEntityManager->createEntity(); goto ccb9c; c92c1: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto D28c0; e3b38: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto e07c0; e8dce: $nodejsSiteCreator->resetPermissions(); goto e3b38; Fb4d1: $siteEntity->setVhostTemplate($vhostTemplate); goto D4462; b2382: b29de: goto Eb4ce; b1eb8: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto c2d74; efeb8: $siteEntity->setUser($siteUser); goto Ce5e6; F6d6d: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\56\56\57\x2e\56\57\162\x65\163\x6f\165\x72\143\x65\163\57\156\147\x69\156\x78\x2f\166\150\x6f\x73\x74\137\x74\x65\x6d\160\x6c\x61\x74\x65\x2f\x72\145\x64\151\162\x65\143\x74"); goto c938e; f58be: $siteEntity->setRootDirectory($domainName); goto F0581; Eb4ce: Db3b7: goto Fb4d1; c6a4b: $certificateEntity->setDefaultCertificate(true); goto c0c04; F5c57: $this->siteEntityManager->updateEntity($siteEntity); goto e84d1; eaf32: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto c2733; F0581: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto Db3b7; } goto De8fa; c2ac6: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto F9883; C2bb0: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto E7d49; d7165: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto D319f; Bea6a: $nodejsSiteCreator->reloadNginxService(); goto e8dce; da79d: $subjectAlternativeNames = []; goto ccd90; a3ab7: $constraintViolationList = new ConstraintViolationList(); goto c0c56; c6b74: if (!(false === is_null($subdomain) && "\167\x77\167" == $subdomain)) { goto Eb058; } goto Db607; A8303: $nodejsSite->setCertificate($certificateEntity); goto E94bd; fc296: $nodejsSiteCreator->installNodejs(); goto Fd584; D2746: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto d4aaf; b1f15: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto ff52d; bda93: $siteConstraints = $this->validator->validate($siteEntity); goto A9471; efc14: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto Bd814; e592a: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto b70ff; C7043: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto cdbb6; fc6ae: $pythonSite = new PythonSite(); goto c02b2; B545f: $subjectAlternativeNames[] = $registrableDomain; goto ccde1; fdfe2: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Fe853; Fe853: if (!(false === empty($redirectionVhostTemplate))) { goto f05f8; } goto a378f; Ff4f0: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto d8f3b; C10b2: $constraintViolationList = new ConstraintViolationList(); goto c9d00; D25be: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Bd587; A4b82: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Fffb1; E995f: if (!(true === is_null($subdomain) || "\x77\x77\x77" == $subdomain)) { goto C4081; } goto Cb262; dba86: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\x2f\x2e\x2e\57\56\x2e\x2f\162\x65\x73\157\x75\x72\x63\145\x73\x2f\x6e\147\x69\156\x78\57\x76\x68\157\163\164\x5f\164\145\x6d\x70\x6c\x61\164\x65\57\x72\145\144\151\x72\x65\143\164\x2d\150\x74\x74\x70\x33"); goto c9ace; dea53: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto F57e3; d1c48: $certificateEntity->setDefaultCertificate(true); goto C7043; E0ee2: C4081: goto E7736; a93b4: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto b6adc; ce64a: $certificateEntity = $this->certificateEntityManager->createEntity(); goto fd308; Bd587: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto fcbd9; ce77c: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto Eb5d8; B536c: goto bd9a6; goto bb47e; e1e75: $pythonSiteCreator->createLogrotateFile(); goto Dbec5; b6adc: $vhostTemplate->build(); goto dea53; D78ca: $pythonSiteCreator->createRootDirectory(); goto e1e75; Dd600: $siteEntity->setUser($siteUser); goto e87d2; B4644: ab4bc: goto ce64a; fcbd9: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto b133a; ce5db: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto a93b4; b133a: $siteEntity = $this->siteEntityManager->createEntity(); goto Bb03e; c02b2: $pythonSite->setUser($siteEntity->getUser()); goto f2b52; F57e3: $this->siteEntityManager->updateEntity($siteEntity); goto Ff4f0; Aa691: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto C8a34; e87d2: $siteEntity->setUserPassword($siteUserPassword); goto a8aef; f2b52: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto dac58; E8a89: if (!(true === is_null($subdomain))) { goto C20d8; } goto f2d4a; A9cfb: $pythonSite->setRegistrableDomain($registrableDomain); goto E7e98; F4ea0: $pythonSite->setPythonSettings($pythonSettingsEntity); goto d6029; feb28: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto ce5db; Bd814: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto E893f; B4f87: $siteEntity->setPythonSettings($pythonSettingsEntity); goto Aa691; cdbb6: $certificateEntity->setCsr($csr); goto Afb59; Bb03e: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto C3cfb; ccde1: B5903: goto E3953; c1fa7: $subjectAlternativeNames = []; goto E8a89; db425: $constraintViolationList->addAll($pythonSettingsConstraints); goto A4b82; fd308: $certificateEntity->setSite($siteEntity); goto a50db; C8a34: $pythonSettingsEntity->setPort($port); goto Ae7db; d4aaf: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto ce77c; ef8a3: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto ab4bc; } goto C10b2; E7e98: $pythonSite->setSubdomain($subdomain); goto A70e3; De975: C20d8: goto Fcd83; Fcd83: if (!(false === is_null($subdomain) && "\167\x77\x77" == $subdomain)) { goto B5903; } goto B545f; A70e3: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto fd05a; Afb59: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto D8443; A6233: $pythonSiteCreator->createUser(); goto D78ca; D8443: $certificateEntity->setCertificate($selfSignedCertificate); goto B992a; ff52d: $csr = $csrGenerator->generate(); goto f7db9; bb47e: Dba4d: goto dba86; f2d4a: $subjectAlternativeNames[] = sprintf("\167\x77\x77\56\x25\x73", $domainName); goto De975; b70ff: $pythonSiteCreator->createNginxVhost(); goto b3991; A9471: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto ef8a3; d8f3b: return $siteEntity; goto Bcdcb; Ae7db: $pythonSettingsEntity->setSite($siteEntity); goto bda93; fd05a: $pythonSite->setCertificate($certificateEntity); goto F4ea0; E893f: $vhostTemplate->resetProcessors(); goto feb28; Eb5d8: $subdomain = $resolvedDomainName->subDomain()->toString(); goto D25be; B992a: $siteEntity->setCertificate($certificateEntity); goto fc6ae; E7736: $siteEntity->setVhostTemplate($vhostTemplate); goto c0e30; E3953: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto b1f15; A15b6: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto A6233; c0e30: $pythonSettingsEntity = new PythonSettingsEntity(); goto B4f87; C3cfb: $siteEntity->setDomainName($domainName); goto Dd600; c9d00: $constraintViolationList->addAll($siteConstraints); goto db425; Ffb42: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\56\56\x2f\x2e\56\x2f\x72\145\x73\157\x75\x72\x63\x65\x73\57\x6e\x67\151\156\x78\57\166\150\157\x73\x74\137\164\145\x6d\160\x6c\x61\164\145\x2f\x72\x65\x64\x69\x72\145\x63\164"); goto B536c; b76e9: $pythonSiteCreator->resetPermissions(); goto efc14; D082a: f05f8: goto E0ee2; b3991: $pythonSiteCreator->reloadNginxService(); goto b76e9; Dbec5: $pythonSiteCreator->writePythonVersionFile(); goto e592a; dac58: $pythonSite->setDomainName($domainName); goto A9cfb; c9ace: bd9a6: goto fdfe2; a378f: $vhostTemplate = sprintf("\45\163\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto D082a; Fffb1: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto B4644; Cb262: if (true === isset($_ENV["\x41\x50\120\137\110\124\124\x50\x33"]) && "\164\x72\165\x65" === $_ENV["\x41\120\120\137\x48\x54\124\x50\63"]) { goto Dba4d; } goto Ffb42; a8aef: $siteEntity->setRootDirectory($domainName); goto E995f; Fc546: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto c1fa7; d6029: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto A15b6; a50db: $rsaKeyGenerator = new RsaKeyGenerator(); goto Fc546; f7db9: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto d1c48; Bcdcb: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto Ddd14; e2297: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto cf5d3; C5d82: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto f8e2a; c7969: return $siteEntity; goto d657f; D4027: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto C3785; Ab5f1: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Eec58; D6540: if (!(true === is_null($subdomain))) { goto Ae7b8; } goto d54df; eefca: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto eea92; eafe9: if (true === isset($_ENV["\x41\120\120\x5f\110\124\124\120\63"]) && "\164\162\165\x65" === $_ENV["\101\x50\120\x5f\110\x54\x54\120\x33"]) { goto ebefa; } goto ba149; f17ca: $siteEntity->setDomainName($domainName); goto bf032; D9e2e: $subjectAlternativeNames = []; goto D6540; ae394: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto D9e2e; d54df: $subjectAlternativeNames[] = sprintf("\167\x77\x77\x2e\45\x73", $domainName); goto c3ba1; cf5d3: $staticSite->setDomainName($domainName); goto B1e7d; f1226: $staticSiteCreator->createIndexHtml(); goto f1320; a26b7: $staticSiteCreator->createRootDirectory(); goto Cccf9; da82e: $certificateEntity->setCertificate($selfSignedCertificate); goto Fbafc; ef7cc: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto fb5eb; A15e8: $certificateEntity->setSite($siteEntity); goto a3ea8; De9b4: $subdomain = $resolvedDomainName->subDomain()->toString(); goto ba918; cc05f: $subjectAlternativeNames[] = $registrableDomain; goto c7046; Bba3d: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto aabb9; bf032: $siteEntity->setUser($siteUser); goto Fa1ea; f1320: $staticSiteCreator->createPrivateKeyAndCertificate(); goto a3096; Cccf9: $staticSiteCreator->createLogrotateFile(); goto f1226; ee94c: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Cff9f; ab0a9: $this->siteEntityManager->updateEntity($siteEntity); goto c7969; Eb44d: $staticSiteCreator->reloadNginxService(); goto B8eab; D14e8: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto f17ca; e324a: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto De9b4; Dc710: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Cc7d6; Fa1ea: $siteEntity->setUserPassword($siteUserPassword); goto Bc41a; Ff8fc: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto E0d34; } goto cc05f; De37c: $staticSite = new StaticSite(); goto b84d5; ba149: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\x2e\x2e\x2f\56\x2e\x2f\x72\x65\163\x6f\x75\162\143\145\x73\57\156\x67\x69\156\170\57\166\x68\x6f\163\164\137\164\145\x6d\x70\x6c\141\x74\145\57\162\x65\x64\x69\x72\x65\x63\x74"); goto ded1a; B1e7d: $staticSite->setRegistrableDomain($registrableDomain); goto Bf309; E6f3c: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto Fa085; b9efc: $vhostTemplate->resetProcessors(); goto D4027; Fbafc: $siteEntity->setCertificate($certificateEntity); goto De37c; C3785: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Bba3d; c4b41: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto d61ec; Eec58: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto ab0a9; Cff9f: $staticSiteCreator = new StaticSiteCreator($staticSite); goto E5956; f8e2a: if (!(false === empty($redirectionVhostTemplate))) { goto Deca8; } goto fa43c; Fa085: $staticSite->setCertificate($certificateEntity); goto ee94c; Abbd6: $siteEntity->setVhostTemplate($vhostTemplate); goto a126d; fd6b2: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto da82e; Ddd14: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto e324a; a3096: $staticSiteCreator->createNginxVhost(); goto Eb44d; Bf309: $staticSite->setSubdomain($subdomain); goto E6f3c; bb330: Deca8: goto a621b; c3ba1: Ae7b8: goto Ff8fc; f9ffa: C38f0: goto C5d82; Cc7d6: $csr = $csrGenerator->generate(); goto ef7cc; ded1a: goto C38f0; goto d65e7; d563e: f459d: goto F9dc1; C1421: $certificateEntity->setCsr($csr); goto fd6b2; e04d0: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto C1421; Bc41a: $siteEntity->setRootDirectory($domainName); goto e6a01; aabb9: $vhostTemplate->build(); goto Ab5f1; fa43c: $vhostTemplate = sprintf("\x25\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto bb330; be78f: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto eefca; ba918: $subdomain = false === empty($subdomain) ? $subdomain : null; goto be78f; d0777: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Dc710; cc13c: $constraintViolationList = new ConstraintViolationList(); goto C5d04; d61ec: throw new \Exception(implode("\x3b\40", $errorMessages)); goto d563e; d65e7: ebefa: goto f8340; F9dc1: $certificateEntity = $this->certificateEntityManager->createEntity(); goto A15e8; beb9c: if (!count($siteConstraints)) { goto f459d; } goto cc13c; fb5eb: $certificateEntity->setDefaultCertificate(true); goto e04d0; c7046: E0d34: goto d0777; f9e1e: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto b9efc; d51a2: $vhostTemplate = new StaticVhostTemplate($staticSite); goto f9e1e; eea92: $siteEntity = $this->siteEntityManager->createEntity(); goto D14e8; C5d04: $constraintViolationList->addAll($siteConstraints); goto c4b41; a126d: $siteConstraints = $this->validator->validate($siteEntity); goto beb9c; b84d5: $staticSite->setUser($siteEntity->getUser()); goto e2297; e6a01: if (!(true === is_null($subdomain) || "\167\167\167" == $subdomain)) { goto E332b; } goto eafe9; a621b: E332b: goto Abbd6; E5956: $staticSiteCreator->createUser(); goto a26b7; f8340: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\x2f\x2e\56\57\56\x2e\57\162\x65\x73\157\165\x72\x63\145\x73\57\x6e\x67\151\x6e\x78\x2f\x76\150\x6f\163\x74\x5f\x74\x65\x6d\160\154\x61\164\145\x2f\162\x65\144\151\162\x65\x63\x74\x2d\x68\164\x74\160\63"); goto f9ffa; B8eab: $staticSiteCreator->resetPermissions(); goto d51a2; a3ea8: $rsaKeyGenerator = new RsaKeyGenerator(); goto ae394; d657f: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto D0c96; d4d45: $reverseProxySite = new ReverseProxySite(); goto f99ae; Db606: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto d91dc; C156f: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Daacf; da18d: $siteConstraints = $this->validator->validate($siteEntity); goto b5280; d260c: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto Dd939; E61b9: throw new \Exception(implode("\73\40", $errorMessages)); goto c20a0; Ab0f9: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto D5f61; df54d: Fa2d6: goto c4e80; C8ee1: if (!(true === is_null($subdomain))) { goto eb443; } goto d034f; Eda09: eca5b: goto Aae9d; B9a2e: C1d73: goto D28d3; cccf7: $siteEntity->setDomainName($domainName); goto B8fa5; B9682: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto E275b; a7bc5: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto F6235; A4190: $reverseProxySite->setSubdomain($subdomain); goto A609d; F6235: $csr = $csrGenerator->generate(); goto B17b8; bcb24: $subjectAlternativeNames[] = $registrableDomain; goto f452a; a316a: goto eca5b; goto df54d; Abbf5: return $siteEntity; goto b6be7; e1ba3: $constraintViolationList->addAll($siteConstraints); goto Cc9b0; B8fa5: $siteEntity->setUser($siteUser); goto Fc406; Be633: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto e5da2; ab916: $reversProxySiteCreator->reloadNginxService(); goto A35bb; ac445: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto A31e9; A609d: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto ff78f; D5f61: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Be633; D5b58: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto de069; d85c1: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto C883f; A31e9: $reversProxySiteCreator->createNginxVhost(); goto ab916; a0387: eb443: goto e2d55; cb2bf: $siteEntity->setRootDirectory($domainName); goto d260c; d67a7: $constraintViolationList = new ConstraintViolationList(); goto e1ba3; c4e80: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\56\56\x2f\x2e\x2e\57\x72\x65\x73\x6f\165\162\143\x65\x73\57\156\x67\151\x6e\x78\x2f\166\150\157\x73\x74\x5f\x74\x65\155\x70\154\x61\164\x65\x2f\x72\145\x64\151\x72\145\x63\x74\55\150\x74\x74\x70\x33"); goto Eda09; de7eb: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto b4d55; d85a5: $rsaKeyGenerator = new RsaKeyGenerator(); goto B9682; Cc819: $reverseProxySite->setRegistrableDomain($registrableDomain); goto A4190; Fc406: $siteEntity->setUserPassword($siteUserPassword); goto cb2bf; A3d98: $subdomain = false === empty($subdomain) ? $subdomain : null; goto db9b4; Fc62a: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto A8051; db9b4: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto C156f; D0c96: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Cfdc8; C5afe: $vhostTemplate = sprintf("\45\x73\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto B9a2e; e63fd: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto a7bc5; ff78f: $reverseProxySite->setCertificate($certificateEntity); goto Db606; d034f: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\x2e\x25\163", $domainName); goto a0387; E275b: $subjectAlternativeNames = []; goto C8ee1; c20a0: Ec00a: goto B8af9; A8051: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E260d; D28d3: C6be0: goto B6d19; D47d0: if (!(false === empty($redirectionVhostTemplate))) { goto C1d73; } goto C5afe; acbcd: $reversProxySiteCreator->createUser(); goto Edc40; A95ea: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto cccf7; Dd939: if (!(true === is_null($subdomain) || "\x77\x77\x77" == $subdomain)) { goto C6be0; } goto e671b; f452a: e114a: goto e63fd; efec2: $vhostTemplate->resetProcessors(); goto Ab0f9; E260d: $this->siteEntityManager->updateEntity($siteEntity); goto Abbf5; f99ae: $reverseProxySite->setUser($siteEntity->getUser()); goto D5b58; Cc9b0: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto E61b9; eef0c: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto acbcd; a9ef1: $certificateEntity->setSite($siteEntity); goto d85a5; B17b8: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto C2937; Cfdc8: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto C5c73; C5c73: $subdomain = $resolvedDomainName->subDomain()->toString(); goto A3d98; Daacf: $siteEntity = $this->siteEntityManager->createEntity(); goto A95ea; C2937: $certificateEntity->setDefaultCertificate(true); goto Bb9ae; cc854: $certificateEntity->setCsr($csr); goto d85c1; e2d55: if (!(false === is_null($subdomain) && "\167\167\167" == $subdomain)) { goto e114a; } goto bcb24; Edc40: $reversProxySiteCreator->createRootDirectory(); goto Cce87; b4d55: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto efec2; E343f: $siteEntity->setCertificate($certificateEntity); goto d4d45; de069: $reverseProxySite->setDomainName($domainName); goto Cc819; B6d19: $siteEntity->setVhostTemplate($vhostTemplate); goto da18d; A35bb: $reversProxySiteCreator->resetPermissions(); goto de7eb; e5da2: $vhostTemplate->build(); goto Fc62a; C883f: $certificateEntity->setCertificate($selfSignedCertificate); goto E343f; d91dc: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto eef0c; B8af9: $certificateEntity = $this->certificateEntityManager->createEntity(); goto a9ef1; Bb9ae: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto cc854; e671b: if (true === isset($_ENV["\x41\120\x50\x5f\110\124\124\x50\x33"]) && "\164\x72\165\145" === $_ENV["\x41\x50\x50\137\110\124\124\x50\x33"]) { goto Fa2d6; } goto c82c3; Aae9d: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto D47d0; Cce87: $reversProxySiteCreator->createLogrotateFile(); goto ac445; b5280: if (!count($siteConstraints)) { goto Ec00a; } goto d67a7; c82c3: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\57\56\56\57\56\x2e\x2f\x72\145\x73\x6f\x75\x72\143\x65\163\57\x6e\147\x69\156\170\x2f\166\x68\157\x73\x74\x5f\x74\x65\155\160\154\x61\164\x65\57\162\x65\144\x69\x72\x65\143\x74"); goto a316a; b6be7: } public function installedWordPressSite(Request $request) : Response { goto Ef3dc; Fa531: ba204: goto ed99d; ed99d: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto d449d; D587d: $siteCredentials = $session->get("\x73\x69\x74\145\103\162\x65\144\x65\x6e\x74\151\x61\154\163"); goto e19d0; E5789: goto Bde2c; goto Fa531; d449d: $response = $this->render("\106\162\157\156\x74\x65\x6e\x64\57\x53\x69\164\x65\x2f\116\145\x77\57\167\x6f\x72\144\x70\162\145\163\x73\x2d\151\x6e\x73\x74\x61\x6c\x6c\145\x64\56\x68\x74\155\x6c\x2e\x74\167\151\147", ["\163\151\164\x65\103\162\145\144\145\156\164\x69\x61\154\163" => $siteCredentials]); goto f1d60; Ef3dc: $session = $request->getSession(); goto D587d; a7799: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\163\x69\x74\x65\x73")); goto E5789; f1d60: return $response; goto cafff; Ec108: return $response; goto ff610; cafff: Bde2c: goto Ec108; e19d0: if (false === empty($siteCredentials)) { goto ba204; } goto a7799; ff610: } private function renderSiteCredentials(array $siteCredentials) : string { goto bb46b; bb46b: $renderedCredentials = ''; goto f4bdc; e920d: return $renderedCredentials; goto b619c; f4bdc: foreach ($siteCredentials as $section => $sectionData) { goto Cd92f; ed5aa: e93ab: goto ba50a; e2a79: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\x25\x73\72\x20\45\x73", $key, $value) . PHP_EOL; e8389: } goto ed5aa; A0656: $renderedCredentials .= "\55\55\55\x2d\55\x2d\x2d\55\55\x2d\55\x2d\x2d\55\55\55\x2d\55\55\55\x2d\x2d\55\55\55\55\x2d\55\x2d\55\55\x2d\x2d\55\55\x2d\55\55\x2d\x2d\55\x2d\x2d\55\x2d\55\55\55\x2d\55\55\x2d\55\55" . PHP_EOL; goto e2a79; ba50a: $renderedCredentials .= PHP_EOL; goto c9d9d; Cd92f: $renderedCredentials .= $section . PHP_EOL; goto A0656; c9d9d: C1b20: goto A6ea2; A6ea2: } goto b0c15; b0c15: Aab2c: goto e920d; b619c: } private function getVhostTemplateEntity(string $name) : mixed { goto e150e; bda9d: d4a86: goto B6bcb; e150e: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto c148d; c148d: if (!(true === is_null($vhostTemplateEntity))) { goto d4a86; } goto B3fb4; B3fb4: throw new \Exception($this->translator->trans("\x56\150\157\x73\x74\40\x54\145\x6d\x70\x6c\141\164\145\40\45\166\x68\x6f\x73\x74\124\145\x6d\x70\x6c\141\164\145\x25\x20\144\157\x65\x73\x20\x6e\157\164\40\145\170\151\x73\164\56", ["\45\x76\150\x6f\x73\164\124\x65\x6d\160\154\x61\x74\x65\x25" => $name])); goto bda9d; B6bcb: return $vhostTemplateEntity; goto beb99; beb99: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto F3e81; D3e9e: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\45\163\72\40\x25\163", $constraint->getPropertyPath(), $constraint->getMessage()); Bca7a: } goto Ca03f; F2b55: return $errorMessages; goto A5c2a; Ca03f: b6f3e: goto F2b55; F3e81: $errorMessages = []; goto D3e9e; A5c2a: } private function generateNameFromDomainName(string $domainName) : string { goto Dcac1; B5cac: $name = $explodedRegistrableDomain[0] ?? ''; goto eb982; E53db: return $name; goto A9136; B2f2e: $explodedRegistrableDomain = explode("\56", $registrableDomain); goto d642a; A2ba6: f3dd4: goto b13d5; D8e00: $explodedSubdomain = explode("\56", $subdomain); goto a9973; b13d5: goto c6347; goto Bdb84; Dcac1: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto B6a06; Bdb84: a26aa: goto B5cac; F302f: if (!(false === empty($subdomain))) { goto f3dd4; } goto D8e00; d642a: if ("\x77\x77\x77" == $subdomain) { goto a26aa; } goto c49b3; eb982: c6347: goto E53db; c49b3: $name = $explodedRegistrableDomain[0] ?? ''; goto F302f; a9973: $name = sprintf("\45\163\55\x25\x73", $explodedRegistrableDomain[0] ?? '', implode("\55", $explodedSubdomain)); goto A2ba6; B6a06: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto cb9d9; cb9d9: $subdomain = $resolvedDomainName->subDomain()->toString(); goto B2f2e; A9136: } private function getUniqueDatabaseName(string $databaseName) : string { goto B1ea7; Ee975: a2fce: goto Dfec7; ca3be: $uniqueDatabaseName = sprintf("\x25\x73\55\144\x62", $uniqueDatabaseName); goto a5102; a7cf4: d7ce4: goto Ac169; B1ea7: $uniqueDatabaseName = $databaseName; goto d848a; ebdbe: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto bc8f7; ba68d: return $uniqueDatabaseName; goto D27f0; Dfec7: if (!(0 < $i)) { goto d7ce4; } goto df5df; D230f: if (true === $databaseExists) { goto a2fce; } goto c6264; F7512: $databases = $databaseConnection->getDatabases(); goto Ee975; Bd4ef: $i = 0; goto ebdbe; bc8f7: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto F7512; d848a: if (!(strlen($uniqueDatabaseName) <= 3)) { goto e57ec; } goto ca3be; e4a0d: $i++; goto D230f; Ac169: $databaseExists = in_array($uniqueDatabaseName, $databases); goto e4a0d; a5102: e57ec: goto Bd4ef; c6264: Af3e2: goto ba68d; df5df: $uniqueDatabaseName = sprintf("\x25\163\55\45\x73", $databaseName, $i); goto a7cf4; D27f0: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto d3604; cca98: D658f: goto F32fc; cb832: $uniqueDatabaseUserName = sprintf("\x25\163\55\x64\x62", $uniqueDatabaseUserName); goto cca98; Edc0e: F34d0: goto Ece9c; D498e: if (false === is_null($databaseUserEntity)) { goto d8624; } goto Fa1a1; d5cfb: d8624: goto Bf4eb; E2d85: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto D658f; } goto cb832; Fa1a1: Ca20f: goto b519d; Ece9c: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto B78cf; D1b9c: $uniqueDatabaseUserName = sprintf("\45\x73\x2d\45\x73", $databaseUserName, $i); goto Edc0e; b519d: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto e1df1; e1df1: return $uniqueDatabaseUserName; goto cc408; B78cf: $i++; goto D498e; F32fc: $i = 0; goto d5cfb; Bf4eb: if (!(0 < $i)) { goto F34d0; } goto D1b9c; d3604: $uniqueDatabaseUserName = $databaseUserName; goto E2d85; cc408: } private function hasPermissions() : bool { goto f9f4e; A1b9d: return false; goto Dc63c; F6596: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto A1905; } goto bc2c7; e0a6f: A1905: goto A1b9d; f9f4e: $user = $this->getUser(); goto F6596; bc2c7: return true; goto e0a6f; Dc63c: } }
